==> cbol-1.5.tgz: cbol-1.5/t.php <==
<?php
 require("config.php");
 require("dbconfig.php");
 require("ref.php");
 require("lang.php");
 /**** @ܼ ********/
  //W
 /************* GET ܼ ***************/
  $N=$_REQUEST['N'];//d 0Gtorrey 1:naves
  $k=$_REQUEST['k'];//dߤe
 $PROGNAME="t.php";
 if ($N<2) $IN=$N+2; //]w
 else
 	$IN=$N;
 $N=$N%2; //2:torrey 3:naves
 if ($N==1) //naves
 {
  $dictname="naves";
  $dictname1="fhlnaves";
 }
 else //torrey
 {
  $dictname="torrey";
  $dictname1="fhltorrey";
 }
  $keyword=sprintf("T%07d",$k);
  //QueryO
 $QUERY="select  $dictname.id,$dictname.topic,$dictname.txt,$dictname1.topic,$dictname1.txt,$dictname1.username from $dictname , $dictname1  where $dictname.id ='$keyword' and $dictname.id=$dictname1.id"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //C@
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
  if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echogb("Ʈwd߿~AO $QUERY !");
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echogb("@ $numrow AƤӦhFAЭקd߱AdI");
	exit;
   }
 if ($numrow==0)
   {
   	echogb("dơAЭקd߱AdI");
	exit;
   }
 /******** LX ********/
 echo "<FONT COLOR=$COLOR><center><table $tabout>\n";
      $ARAW=db_fetch_row($result,0); //Ū@O
        $special=htmlspecialchars($ARAW[0]);//SrBz id
      echogb("<tr><td>s</td><td>$special</td></tr>\n");
        $special=htmlspecialchars($ARAW[1]);//SrBz topic
        $special1=htmlspecialchars($ARAW[3]);//SrBz topic
      echogb("<tr><TD>DD</td><td>$special ($special1)</td></tr>\n");
      if (strlen($ARAW[4])>0)
      {
      	$special2=$ARAW[4];//SrBz
	$special2=tref($special2,$db_conn,$IN);
	$special2=ref($special2,"Mt",1,$db_conn,"unv");
	$special2=ereg_replace(" (.+)\(([[:alnum:]]+)\)",
        " <a href=\"$STP?N={$IN}&keyword=\\1\">\\1</a>(<a href=\"$STP?N={$N}&keyword=\\2\">\\2</a>)", $special2);
      	echogb("<tr><TD>夺e</td><td><pre>$special2</pre></td></tr>\n");
      }
      if (strlen($ARAW[2])>0)
      {
      	$special1=$ARAW[2];//SrBz
	$special1=ref($special1,"Mt",1,$db_conn,"unv");
	$special1=ereg_replace("See ([[:alnum:]]+)([, \r\n])",
        "See <a href=\"$STP?N={$N}&keyword=\\1\">\\1</a>\\2", $special1);
      	echogb("<tr><TD>e</td><td><pre>$special1</pre></td></tr>\n");
      }
   echo "</table>\n";
   echogb("<a href=\"$RETURNADD1\">sd</a></center><br>\n");
?>

==> cbol-1.7.tgz: cbol-1.7/t.php <==
<?php
 require("config.php");
 require("dbconfig.php");
 require("ref.php");
 require("lang.php");
 /**** @ܼ ********/
  //W
 /************* GET ܼ ***************/
  $N=(int) $_REQUEST['N'];//d 0Gtorrey 1:naves
  $k=(int) $_REQUEST['k'];//dߤe
 $PROGNAME="t.php";
 if ($N<2) $IN=$N+2; //]w
 else
 	$IN=$N;
 $N=$N%2; //2:torrey 3:naves
 if ($N==1) //naves
 {
  $dictname="naves";
  $dictname1="fhlnaves";
 }
 else //torrey
 {
  $dictname="torrey";
  $dictname1="fhltorrey";
 }
  $keyword=sprintf("T%07d",$k);
  //QueryO
 $QUERY="select  $dictname.id,$dictname.topic,$dictname.txt,$dictname1.topic,$dictname1.txt,$dictname1.username from $dictname , $dictname1  where $dictname.id ='$keyword' and $dictname.id=$dictname1.id"; 
  //TableXSOѼ
 $tabout="border=1";
  //Jܼ
  //C@
 $PGNUM=50;
 // Primary Key	
 $PKEY="oid";
 $KEYCOLOR="\"#FF0000\"";
 $COLOR="\"#000000\"";
 
 $db_conn=db_connect("host=localhost dbname=$DBNAME");
 db_set_encoding($db_conn,"BIG5");
  if ($GBCODE==0)
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=big5\">";
 else
        echo "<meta http-equiv=\"Content-Type\" CONTENT=\"text/html; charset=gb2312\">";
 /******** }ldƮw ********/
 $result=db_exec($db_conn,$QUERY);
 if (!$result){
                        echogb("Ʈwd߿~AO $QUERY !");
                        exit;
 }
 $numrow=db_NumRows($result);  
 /****** ȶȬOB˵ *********/
 if ($numrow>500)
   {
   	echogb("@ $numrow AƤӦhFAЭקd߱AdI");
	exit;
   }
 if ($numrow==0)
   {
   	echogb("dơAЭקd߱AdI");
	exit;
   }
 /******** LX ********/
 echo "<FONT COLOR=$COLOR><center><table $tabout>\n";
      $ARAW=db_fetch_row($result,0); //Ū@O
        $special=htmlspecialchars($ARAW[0]);//SrBz id
      echogb("<tr><td>s</td><td>$special</td></tr>\n");
        $special=htmlspecialchars($ARAW[1]);//SrBz topic
        $special1=htmlspecialchars($ARAW[3]);//SrBz topic
      echogb("<tr><TD>DD</td><td>$special ($special1)</td></tr>\n");
      if (strlen($ARAW[4])>0)
      {
      	$special2=$ARAW[4];//SrBz
	$special2=tref($special2,$db_conn,$IN);
	$special2=ref($special2,"Mt",1,$db_conn,"unv");
	$special2=ereg_replace(" (.+)\(([[:alnum:]]+)\)",
        " <a href=\"$STP?N={$IN}&keyword=\\1\">\\1</a>(<a href=\"$STP?N={$N}&keyword=\\2\">\\2</a>)", $special2);
      	echogb("<tr><TD>夺e</td><td><pre>$special2</pre></td></tr>\n");
      }
      if (strlen($ARAW[2])>0)
      {
      	$special1=$ARAW[2];//SrBz
	$special1=ref($special1,"Mt",1,$db_conn,"unv");
	$special1=ereg_replace("See ([[:alnum:]]+)([, \r\n])",
        "See <a href=\"$STP?N={$N}&keyword=\\1\">\\1</a>\\2", $special1);
      	echogb("<tr><TD>e</td><td><pre>$special1</pre></td></tr>\n");
      }
   echo "</table>\n";
   echogb("<a href=\"$RETURNADD1\">sd</a></center><br>\n");
?>
